==> perl-DateTime-Locale-1.22-1-src.tar.xz: DateTime-Locale-1.22/share/sq-XK.pl <==
{
  am_pm_abbreviated => [
    "e paradites",
    "e pasdites",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss, v",
    Hmv => "HH:mm, v",
    M => "L",
    MEd => "E, d.M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-one" => "'java' W 'e' MMM",
    "MMMMW-count-other" => "'java' W 'e' MMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "d.M",
    Md => "d.M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a, v",
    hmv => "h:mm a, v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E, d.M.y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ, y",
    yQQQQ => "QQQQ, y",
    "yw-count-one" => "'java' w 'e' Y",
    "yw-count-other" => "'java' w 'e' Y",
  },
  code => "sq-XK",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d.M.yy",
  datetime_format_full => "{1} 'n\N{U+00eb}' {0}",
  datetime_format_long => "{1} 'n\N{U+00eb}' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "H\N{U+00eb}n",
    "Mar",
    "M\N{U+00eb}r",
    "Enj",
    "Pre",
    "Sht",
    "Die",
  ],
  day_format_narrow => [
    "H",
    "M",
    "M",
    "E",
    "P",
    "Sh",
    "D",
  ],
  day_format_wide => [
    "e h\N{U+00eb}n\N{U+00eb}",
    "e mart\N{U+00eb}",
    "e m\N{U+00eb}rkur\N{U+00eb}",
    "e enjte",
    "e premte",
    "e shtun\N{U+00eb}",
    "e diel",
  ],
  day_stand_alone_abbreviated => [
    "H\N{U+00eb}n",
    "Mar",
    "M\N{U+00eb}r",
    "Enj",
    "Pre",
    "Sht",
    "Die",
  ],
  day_stand_alone_narrow => [
    "H",
    "M",
    "M",
    "E",
    "P",
    "Sh",
    "D",
  ],
  day_stand_alone_wide => [
    "E h\N{U+00eb}n\N{U+00eb}",
    "E mart\N{U+00eb}",
    "E m\N{U+00eb}rkur\N{U+00eb}",
    "E enjte",
    "E premte",
    "E shtun\N{U+00eb}",
    "E diel",
  ],
  era_abbreviated => [
    "p.K.",
    "mb.K.",
  ],
  era_narrow => [
    "p.K.",
    "mb.K.",
  ],
  era_wide => [
    "para Krishtit",
    "mbas Krishtit",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Albanian",
  month_format_abbreviated => [
    "jan",
    "shk",
    "mar",
    "pri",
    "maj",
    "qer",
    "korr",
    "gush",
    "sht",
    "tet",
    "n\N{U+00eb}n",
    "dhj",
  ],
  month_format_narrow => [
    "j",
    "sh",
    "m",
    "p",
    "m",
    "q",
    "k",
    "g",
    "sh",
    "t",
    "n",
    "dh",
  ],
  month_format_wide => [
    "janar",
    "shkurt",
    "mars",
    "prill",
    "maj",
    "qershor",
    "korrik",
    "gusht",
    "shtator",
    "tetor",
    "n\N{U+00eb}ntor",
    "dhjetor",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Shk",
    "Mar",
    "Pri",
    "Maj",
    "Qer",
    "Korr",
    "Gush",
    "Sht",
    "Tet",
    "N\N{U+00eb}n",
    "Dhj",
  ],
  month_stand_alone_narrow => [
    "J",
    "Sh",
    "M",
    "P",
    "M",
    "Q",
    "K",
    "G",
    "Sh",
    "T",
    "N",
    "Dh",
  ],
  month_stand_alone_wide => [
    "Janar",
    "Shkurt",
    "Mars",
    "Prill",
    "Maj",
    "Qershor",
    "Korrik",
    "Gusht",
    "Shtator",
    "Tetor",
    "N\N{U+00eb}ntor",
    "Dhjetor",
  ],
  name => "Albanian Kosovo",
  native_language => "shqip",
  native_name => "shqip Kosov\N{U+00eb}",
  native_script => undef,
  native_territory => "Kosov\N{U+00eb}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "tremujori I",
    "tremujori II",
    "tremujori III",
    "tremujori IV",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "tremujori i par\N{U+00eb}",
    "tremujori i dyt\N{U+00eb}",
    "tremujori i tret\N{U+00eb}",
    "tremujori i kat\N{U+00eb}rt",
  ],
  quarter_stand_alone_abbreviated => [
    "Tremujori I",
    "Tremujori II",
    "Tremujori III",
    "Tremujori IV",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Tremujori i 1-r\N{U+00eb}",
    "Tremujori i 2-t\N{U+00eb}",
    "Tremujori i 3-t\N{U+00eb}",
    "Tremujori i 4-t",
  ],
  script => undef,
  territory => "Kosovo",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 33,
}

==> perl-DateTime-Locale-1.24-1-src.tar.xz: DateTime-Locale-1.24/share/sq-XK.pl <==
{
  am_pm_abbreviated => [
    "p.d.",
    "m.d.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss, v",
    Hmv => "HH:mm, v",
    M => "L",
    MEd => "E, d.M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-one" => "'java' W 'e' MMMM",
    "MMMMW-count-other" => "'java' W 'e' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "d.M",
    Md => "d.M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a, v",
    hmv => "h:mm a, v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E, d.M.y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ, y",
    yQQQQ => "QQQQ, y",
    "yw-count-one" => "'java' w 'e' Y",
    "yw-count-other" => "'java' w 'e' Y",
  },
  code => "sq-XK",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d.M.yy",
  datetime_format_full => "{1} 'n\N{U+00eb}' {0}",
  datetime_format_long => "{1} 'n\N{U+00eb}' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "H\N{U+00eb}n",
    "Mar",
    "M\N{U+00eb}r",
    "Enj",
    "Pre",
    "Sht",
    "Die",
  ],
  day_format_narrow => [
    "h",
    "m",
    "m",
    "e",
    "p",
    "sh",
    "d",
  ],
  day_format_wide => [
    "e h\N{U+00eb}n\N{U+00eb}",
    "e mart\N{U+00eb}",
    "e m\N{U+00eb}rkur\N{U+00eb}",
    "e enjte",
    "e premte",
    "e shtun\N{U+00eb}",
    "e diel",
  ],
  day_stand_alone_abbreviated => [
    "h\N{U+00eb}n",
    "mar",
    "m\N{U+00eb}r",
    "enj",
    "pre",
    "sht",
    "die",
  ],
  day_stand_alone_narrow => [
    "h",
    "m",
    "m",
    "e",
    "p",
    "sh",
    "d",
  ],
  day_stand_alone_wide => [
    "e h\N{U+00eb}n\N{U+00eb}",
    "e mart\N{U+00eb}",
    "e m\N{U+00eb}rkur\N{U+00eb}",
    "e enjte",
    "e premte",
    "e shtun\N{U+00eb}",
    "e diel",
  ],
  era_abbreviated => [
    "p.K.",
    "mb.K.",
  ],
  era_narrow => [
    "p.K.",
    "mb.K.",
  ],
  era_wide => [
    "para Krishtit",
    "mbas Krishtit",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Albanian",
  month_format_abbreviated => [
    "jan",
    "shk",
    "mar",
    "pri",
    "maj",
    "qer",
    "korr",
    "gush",
    "sht",
    "tet",
    "n\N{U+00eb}n",
    "dhj",
  ],
  month_format_narrow => [
    "j",
    "sh",
    "m",
    "p",
    "m",
    "q",
    "k",
    "g",
    "sh",
    "t",
    "n",
    "dh",
  ],
  month_format_wide => [
    "janar",
    "shkurt",
    "mars",
    "prill",
    "maj",
    "qershor",
    "korrik",
    "gusht",
    "shtator",
    "tetor",
    "n\N{U+00eb}ntor",
    "dhjetor",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "shk",
    "mar",
    "pri",
    "maj",
    "qer",
    "korr",
    "gush",
    "sht",
    "tet",
    "n\N{U+00eb}n",
    "dhj",
  ],
  month_stand_alone_narrow => [
    "j",
    "sh",
    "m",
    "p",
    "m",
    "q",
    "k",
    "g",
    "sh",
    "t",
    "n",
    "dh",
  ],
  month_stand_alone_wide => [
    "janar",
    "shkurt",
    "mars",
    "prill",
    "maj",
    "qershor",
    "korrik",
    "gusht",
    "shtator",
    "tetor",
    "n\N{U+00eb}ntor",
    "dhjetor",
  ],
  name => "Albanian Kosovo",
  native_language => "shqip",
  native_name => "shqip Kosov\N{U+00eb}",
  native_script => undef,
  native_territory => "Kosov\N{U+00eb}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "tremujori I",
    "tremujori II",
    "tremujori III",
    "tremujori IV",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "tremujori i par\N{U+00eb}",
    "tremujori i dyt\N{U+00eb}",
    "tremujori i tret\N{U+00eb}",
    "tremujori i kat\N{U+00eb}rt",
  ],
  quarter_stand_alone_abbreviated => [
    "Tremujori I",
    "Tremujori II",
    "Tremujori III",
    "Tremujori IV",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Tremujori i 1-r\N{U+00eb}",
    "Tremujori i 2-t\N{U+00eb}",
    "Tremujori i 3-t\N{U+00eb}",
    "Tremujori i 4-t",
  ],
  script => undef,
  territory => "Kosovo",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 35,
}
